##  Limitations
  * You can connect only one SAP LeanIX workspace to a Jira account.
  * You can only map text fields from your fact sheets. These correspond with the SAP LeanIX field type "string," including fields like name, description, or alias. Read more about field types in the topic [Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet fields are designed for storing information on specific data points. You can configure existing fields and create custom ones.").
  * A fact sheet can only be paired with one Jira issue type. However, you can sync a single Jira issue type with multiple fact sheet types.
  * There are no restrictions on fact sheet creation in Jira. After you integrate an SAP LeanIX workspace with Jira, all Jira users can create fact sheets within Jira issues.
